@@ -1,10 +1,7 @@
 import abc
-from typing import Generic, TypeVar
 
 from pydantic import BaseModel
 
-T = TypeVar("T", bound=BaseModel)
-
 
 class StorageException(Exception):
     pass
@@ -18,7 +15,7 @@ class MissingStateException(StorageException):
     pass
 
 
-class StateStorage(abc.ABC, Generic[T]):
+class StateStorage[T: BaseModel](abc.ABC):
     @abc.abstractmethod
     async def store(self, state: T) -> None:
         pass
